@@ -5,9 +5,9 @@ var canDistinguishSparseFromUndefined = 0 in [undefined]; // IE 6 - 8 have a bug
 var ifHasDenseUndefinedsIt = canDistinguishSparseFromUndefined ? it : xit;
 var undefinedIfNoSparseBug = canDistinguishSparseFromUndefined ? undefined : { valueOf: function () { return 0; } };
 var hasStrictMode = (function () {
-  'use strict';
+    'use strict';
 
-   return !this;
+    return !this;
 }());
 var ifHasStrictIt = hasStrictMode ? it : xit;
 
@@ -163,12 +163,14 @@ describe('Array', function () {
         });
 
         it('should set the right context when given none', function () {
+            /* eslint-disable array-callback-return */
             var context;
             [1].some(function () { context = this; });
             expect(context).toBe(function () { return this; }.call());
         });
 
         it('should return false if it runs to the end', function () {
+            /* eslint-disable array-callback-return */
             actual = testSubject.some(function () {});
             expect(actual).toBeFalsy();
         });
@@ -261,6 +263,7 @@ describe('Array', function () {
         });
 
         it('should set the right context when given none', function () {
+            /* eslint-disable array-callback-return */
             var context;
             [1].every(function () { context = this; });
             expect(context).toBe(function () { return this; }.call());
@@ -645,6 +648,7 @@ describe('Array', function () {
             });
 
             it('should set the right context when given none', function () {
+                /* eslint-disable array-callback-return */
                 var context;
                 [1].filter(function () { context = this; });
                 expect(context).toBe(function () { return this; }.call());
@@ -1483,10 +1487,10 @@ describe('Array', function () {
             tooBig[8] = 'x';
 
             justFine.splice(1, 1);
-			expect(8 in justFine).toBe(false);
+            expect(8 in justFine).toBe(false);
             expect(justFine.indexOf('x')).toBe(9);
             tooBig.splice(1, 1);
-			expect(6 in tooBig).toBe(false);
+            expect(6 in tooBig).toBe(false);
             expect(tooBig.indexOf('x')).toBe(7);
         });
     });
@@ -1584,7 +1588,7 @@ describe('Array', function () {
 
         it('works with `arguments`', function () {
             var obj = (function () {
-              return arguments;
+                return arguments;
             }(1, 2, 3, 4));
             var result = Array.prototype.slice.call(obj, 1, 3);
             expect(result).toEqual([2, 3]);
@@ -1595,6 +1599,14 @@ describe('Array', function () {
             var result = Array.prototype.slice.call(obj, 1, 3);
             expect(result).toEqual(['2', '3']);
         });
+
+        /* globals document */
+        if (typeof document !== 'undefined') {
+            it('should be able to slice a NodeList', function () {
+                var nodes = document.getElementsByTagName('div');
+                expect(Array.isArray(Array.prototype.slice.call(nodes))).toBe(true);
+            });
+        }
     });
 
     describe('#sort()', function () {
@@ -1862,49 +1874,49 @@ describe('Array', function () {
             });
 
             it('should sort objects ascending with length', function () {
-                    var actual = {
-                        0: 5,
-                        1: 2,
-                        2: 4,
-                        3: 6,
-                        4: 1,
-                        5: 3,
-                        length: 6
-                    };
-                    var expected = {
-                        0: 1,
-                        1: 2,
-                        2: 3,
-                        3: 4,
-                        4: 5,
-                        5: 6,
-                        length: 6
-                    };
-                    Array.prototype.sort.call(actual);
-                    expect(actual).toEqual(expected);
+                var actual = {
+                    0: 5,
+                    1: 2,
+                    2: 4,
+                    3: 6,
+                    4: 1,
+                    5: 3,
+                    length: 6
+                };
+                var expected = {
+                    0: 1,
+                    1: 2,
+                    2: 3,
+                    3: 4,
+                    4: 5,
+                    5: 6,
+                    length: 6
+                };
+                Array.prototype.sort.call(actual);
+                expect(actual).toEqual(expected);
             });
 
             it('should sort objects descending with length', function () {
-                    var actual = {
-                        0: 5,
-                        1: 2,
-                        2: 4,
-                        3: 6,
-                        4: 1,
-                        5: 3,
-                        length: 6
-                    };
-                    var expected = {
-                        0: 6,
-                        1: 5,
-                        2: 4,
-                        3: 3,
-                        4: 2,
-                        5: 1,
-                        length: 6
-                    };
-                    Array.prototype.sort.call(actual, descending);
-                    expect(actual).toEqual(expected);
+                var actual = {
+                    0: 5,
+                    1: 2,
+                    2: 4,
+                    3: 6,
+                    4: 1,
+                    5: 3,
+                    length: 6
+                };
+                var expected = {
+                    0: 6,
+                    1: 5,
+                    2: 4,
+                    3: 3,
+                    4: 2,
+                    5: 1,
+                    length: 6
+                };
+                Array.prototype.sort.call(actual, descending);
+                expect(actual).toEqual(expected);
             });
 
             it('should sort objects descending with mixed content types and with length', function () {
