@@ -6,6 +6,8 @@ describe('global methods', function () {
     var foo = function foo() {};
     var functionsHaveNames = foo.name === 'foo';
     var ifFunctionsHaveNamesIt = functionsHaveNames ? it : xit;
+    var hasSymbols = typeof Symbol === 'function' && typeof Symbol.iterator === 'symbol';
+    var ifSymbolsIt = hasSymbols ? it : xit;
 
     var is = function (x, y) {
         if (x === 0 && y === 0) {
@@ -48,9 +50,9 @@ describe('global methods', function () {
             expect(parseInt('  42')).toBe(parseInt('42', 10));
             expect(parseInt('  08')).toBe(parseInt('08', 10));
 
-            var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
-                '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' +
-                '\u2029\uFEFF';
+            var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003'
+                + '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028'
+                + '\u2029\uFEFF';
             expect(parseInt(ws + '08')).toBe(parseInt('08', 10));
             expect(parseInt(ws + '0x16')).toBe(parseInt('0x16', 16));
         });
@@ -69,10 +71,16 @@ describe('global methods', function () {
         });
 
         it('NaN parsing', function () {
+            expect(parseInt()).toBeNaN();
             expect(parseInt(undefined)).toBeNaN();
             expect(parseInt(null)).toBeNaN();
             expect(parseInt(NaN)).toBeNaN();
         });
+
+        ifSymbolsIt('throws on symbols', function () {
+            expect(function () { parseInt(Symbol('')); }).toThrow();
+            expect(function () { parseInt(Object(Symbol(''))); }).toThrow();
+        });
         /* eslint-enable radix */
     });
 
